# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ni.measurementlink.sessionmanagement.v1 import session_management_service_pb2 as ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2


class SessionManagementServiceStub(object):
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ReserveSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/ReserveSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsResponse.FromString,
                )
        self.UnreserveSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnreserveSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsResponse.FromString,
                )
        self.RegisterSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/RegisterSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsResponse.FromString,
                )
        self.UnregisterSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnregisterSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsResponse.FromString,
                )
        self.ReserveAllRegisteredSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/ReserveAllRegisteredSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsResponse.FromString,
                )
        self.RegisterMultiplexerSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/RegisterMultiplexerSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsResponse.FromString,
                )
        self.UnregisterMultiplexerSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnregisterMultiplexerSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsResponse.FromString,
                )
        self.GetMultiplexerSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetMultiplexerSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsResponse.FromString,
                )
        self.GetAllRegisteredMultiplexerSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetAllRegisteredMultiplexerSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsResponse.FromString,
                )
        self.GetSessions = channel.unary_unary(
                '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetSessions',
                request_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsRequest.SerializeToString,
                response_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsResponse.FromString,
                )


class SessionManagementServiceServicer(object):
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site.
    """

    def ReserveSessions(self, request, context):
        """Reserve session(s) for the given I/O resources (pins, relays, channels), sites, and instrument type ID and returns the information needed to create or access the session.
        Also reserves the session so other processes cannot access it with a ReserveSessions() call.
        Status Codes for errors:
        - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map
        - Pin or relay name does not match any pin, pin group, relay, or relay group names in the pin map
        - Timeout specified is less than -1.
        - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
        - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnreserveSessions(self, request, context):
        """Unreserves sessions so they can be accessed by other clients.
        - RESOURCE_EXHAUSTED:
        - Error occurred while unreserving sessions.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterSessions(self, request, context):
        """Registers the sessions with this service. Indicates that the sessions are open and will need to be closed later.
        Status Codes for errors:
        - ALREADY_EXISTS:
        - Session by the same name is already registered.
        - INVALID_ARGUMENT:
        - Session names list has an empty string.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterSessions(self, request, context):
        """Unregisters the sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ReserveAllRegisteredSessions(self, request, context):
        """Reserves and gets all sessions currently registered with this service.
        - INVALID_ARGUMENT:
        - Timeout specified is less than -1.
        - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterMultiplexerSessions(self, request, context):
        """Registers the multiplexer sessions with this service. Indicates that the sessions are open and will need to be closed later.
        Status Codes for errors:
        - ALREADY_EXISTS:
        - Session by the same name is already registered.
        - INVALID_ARGUMENT:
        - Session names list has an empty string.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UnregisterMultiplexerSessions(self, request, context):
        """Unregisters the multiplexer sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetMultiplexerSessions(self, request, context):
        """Gets all the connected multiplexer session(s) for the given pin map context and returns information needed to create or access the session.
        Status Codes for errors:
        - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map.
        - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetAllRegisteredMultiplexerSessions(self, request, context):
        """Gets all multiplexer sessions currently registered with this service.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetSessions(self, request, context):
        """Gets all reserved or registered sessions for the specified instrument and multiplexer types.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SessionManagementServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ReserveSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ReserveSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsResponse.SerializeToString,
            ),
            'UnreserveSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.UnreserveSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsResponse.SerializeToString,
            ),
            'RegisterSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsResponse.SerializeToString,
            ),
            'UnregisterSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsResponse.SerializeToString,
            ),
            'ReserveAllRegisteredSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.ReserveAllRegisteredSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsResponse.SerializeToString,
            ),
            'RegisterMultiplexerSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterMultiplexerSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsResponse.SerializeToString,
            ),
            'UnregisterMultiplexerSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.UnregisterMultiplexerSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsResponse.SerializeToString,
            ),
            'GetMultiplexerSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetMultiplexerSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsResponse.SerializeToString,
            ),
            'GetAllRegisteredMultiplexerSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetAllRegisteredMultiplexerSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsResponse.SerializeToString,
            ),
            'GetSessions': grpc.unary_unary_rpc_method_handler(
                    servicer.GetSessions,
                    request_deserializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsRequest.FromString,
                    response_serializer=ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ni.measurementlink.sessionmanagement.v1.SessionManagementService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class SessionManagementService(object):
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site.
    """

    @staticmethod
    def ReserveSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/ReserveSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnreserveSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnreserveSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnreserveSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/RegisterSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnregisterSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ReserveAllRegisteredSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/ReserveAllRegisteredSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.ReserveAllRegisteredSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterMultiplexerSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/RegisterMultiplexerSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.RegisterMultiplexerSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UnregisterMultiplexerSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/UnregisterMultiplexerSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.UnregisterMultiplexerSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetMultiplexerSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetMultiplexerSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetMultiplexerSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetAllRegisteredMultiplexerSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetAllRegisteredMultiplexerSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetAllRegisteredMultiplexerSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetSessions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/ni.measurementlink.sessionmanagement.v1.SessionManagementService/GetSessions',
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsRequest.SerializeToString,
            ni_dot_measurementlink_dot_sessionmanagement_dot_v1_dot_session__management__service__pb2.GetSessionsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ni/measurementlink/sessionmanagement/v1/session_management_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ni.measurementlink import pin_map_context_pb2 as ni_dot_measurementlink_dot_pin__map__context__pb2
import session_pb2 as session__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHni/measurementlink/sessionmanagement/v1/session_management_service.proto\x12\'ni.measurementlink.sessionmanagement.v1\x1a(ni/measurementlink/pin_map_context.proto\x1a\rsession.proto\"\x8b\x02\n\x12SessionInformation\x12\'\n\x07session\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x14\n\x0c\x63hannel_list\x18\x03 \x01(\t\x12\x1a\n\x12instrument_type_id\x18\x04 \x01(\t\x12\x16\n\x0esession_exists\x18\x05 \x01(\x08\x12\x18\n\x10session_reserved\x18\x07 \x01(\x08\x12Q\n\x10\x63hannel_mappings\x18\x06 \x03(\x0b\x32\x37.ni.measurementlink.sessionmanagement.v1.ChannelMapping\"\x88\x01\n\x0e\x43hannelMapping\x12\x19\n\x11pin_or_relay_name\x18\x01 \x01(\t\x12\x0c\n\x04site\x18\x02 \x01(\x05\x12\x0f\n\x07\x63hannel\x18\x03 \x01(\t\x12!\n\x19multiplexer_resource_name\x18\x04 \x01(\t\x12\x19\n\x11multiplexer_route\x18\x05 \x01(\t\"\x94\x01\n\x1dMultiplexerSessionInformation\x12\'\n\x07session\x18\x01 \x01(\x0b\x32\x16.nidevice_grpc.Session\x12\x15\n\rresource_name\x18\x02 \x01(\t\x12\x1b\n\x13multiplexer_type_id\x18\x03 \x01(\t\x12\x16\n\x0esession_exists\x18\x04 \x01(\x08\"\xad\x01\n\x16ReserveSessionsRequest\x12:\n\x0fpin_map_context\x18\x01 \x01(\x0b\x32!.ni.measurementlink.PinMapContext\x12\x1a\n\x12pin_or_relay_names\x18\x02 \x03(\t\x12\x1a\n\x12instrument_type_id\x18\x03 \x01(\t\x12\x1f\n\x17timeout_in_milliseconds\x18\x04 \x01(\x05\"\xb0\x03\n\x17ReserveSessionsResponse\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\x12\x64\n\x14multiplexer_sessions\x18\x02 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation\x12k\n\x0egroup_mappings\x18\x03 \x03(\x0b\x32S.ni.measurementlink.sessionmanagement.v1.ReserveSessionsResponse.GroupMappingsEntry\x1as\n\x12GroupMappingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12L\n\x05value\x18\x02 \x01(\x0b\x32=.ni.measurementlink.sessionmanagement.v1.ResolvedPinsOrRelays:\x02\x38\x01\"i\n\x18UnreserveSessionsRequest\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\"\x1b\n\x19UnreserveSessionsResponse\"h\n\x17RegisterSessionsRequest\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\"\x1a\n\x18RegisterSessionsResponse\"j\n\x19UnregisterSessionsRequest\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\"\x1c\n\x1aUnregisterSessionsResponse\"b\n#ReserveAllRegisteredSessionsRequest\x12\x1f\n\x17timeout_in_milliseconds\x18\x01 \x01(\x05\x12\x1a\n\x12instrument_type_id\x18\x02 \x01(\t\"u\n$ReserveAllRegisteredSessionsResponse\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\"\x8a\x01\n\"RegisterMultiplexerSessionsRequest\x12\x64\n\x14multiplexer_sessions\x18\x01 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation\"%\n#RegisterMultiplexerSessionsResponse\"\x8c\x01\n$UnregisterMultiplexerSessionsRequest\x12\x64\n\x14multiplexer_sessions\x18\x01 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation\"\'\n%UnregisterMultiplexerSessionsResponse\"x\n\x1dGetMultiplexerSessionsRequest\x12:\n\x0fpin_map_context\x18\x01 \x01(\x0b\x32!.ni.measurementlink.PinMapContext\x12\x1b\n\x13multiplexer_type_id\x18\x02 \x01(\t\"\x86\x01\n\x1eGetMultiplexerSessionsResponse\x12\x64\n\x14multiplexer_sessions\x18\x01 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation\"I\n*GetAllRegisteredMultiplexerSessionsRequest\x12\x1b\n\x13multiplexer_type_id\x18\x01 \x01(\t\"\x93\x01\n+GetAllRegisteredMultiplexerSessionsResponse\x12\x64\n\x14multiplexer_sessions\x18\x01 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation\"2\n\x14ResolvedPinsOrRelays\x12\x1a\n\x12pin_or_relay_names\x18\x01 \x03(\t\"M\n\x12GetSessionsRequest\x12\x1a\n\x12instrument_type_id\x18\x01 \x01(\t\x12\x1b\n\x13multiplexer_type_id\x18\x02 \x01(\t\"\xca\x01\n\x13GetSessionsResponse\x12M\n\x08sessions\x18\x01 \x03(\x0b\x32;.ni.measurementlink.sessionmanagement.v1.SessionInformation\x12\x64\n\x14multiplexer_sessions\x18\x02 \x03(\x0b\x32\x46.ni.measurementlink.sessionmanagement.v1.MultiplexerSessionInformation2\xcc\r\n\x18SessionManagementService\x12\x94\x01\n\x0fReserveSessions\x12?.ni.measurementlink.sessionmanagement.v1.ReserveSessionsRequest\x1a@.ni.measurementlink.sessionmanagement.v1.ReserveSessionsResponse\x12\x9a\x01\n\x11UnreserveSessions\x12\x41.ni.measurementlink.sessionmanagement.v1.UnreserveSessionsRequest\x1a\x42.ni.measurementlink.sessionmanagement.v1.UnreserveSessionsResponse\x12\x97\x01\n\x10RegisterSessions\x12@.ni.measurementlink.sessionmanagement.v1.RegisterSessionsRequest\x1a\x41.ni.measurementlink.sessionmanagement.v1.RegisterSessionsResponse\x12\x9d\x01\n\x12UnregisterSessions\x12\x42.ni.measurementlink.sessionmanagement.v1.UnregisterSessionsRequest\x1a\x43.ni.measurementlink.sessionmanagement.v1.UnregisterSessionsResponse\x12\xbb\x01\n\x1cReserveAllRegisteredSessions\x12L.ni.measurementlink.sessionmanagement.v1.ReserveAllRegisteredSessionsRequest\x1aM.ni.measurementlink.sessionmanagement.v1.ReserveAllRegisteredSessionsResponse\x12\xb8\x01\n\x1bRegisterMultiplexerSessions\x12K.ni.measurementlink.sessionmanagement.v1.RegisterMultiplexerSessionsRequest\x1aL.ni.measurementlink.sessionmanagement.v1.RegisterMultiplexerSessionsResponse\x12\xbe\x01\n\x1dUnregisterMultiplexerSessions\x12M.ni.measurementlink.sessionmanagement.v1.UnregisterMultiplexerSessionsRequest\x1aN.ni.measurementlink.sessionmanagement.v1.UnregisterMultiplexerSessionsResponse\x12\xa9\x01\n\x16GetMultiplexerSessions\x12\x46.ni.measurementlink.sessionmanagement.v1.GetMultiplexerSessionsRequest\x1aG.ni.measurementlink.sessionmanagement.v1.GetMultiplexerSessionsResponse\x12\xd0\x01\n#GetAllRegisteredMultiplexerSessions\x12S.ni.measurementlink.sessionmanagement.v1.GetAllRegisteredMultiplexerSessionsRequest\x1aT.ni.measurementlink.sessionmanagement.v1.GetAllRegisteredMultiplexerSessionsResponse\x12\x88\x01\n\x0bGetSessions\x12;.ni.measurementlink.sessionmanagement.v1.GetSessionsRequest\x1a<.ni.measurementlink.sessionmanagement.v1.GetSessionsResponseB\xf5\x01\n+com.ni.measurementlink.sessionmanagement.v1B\x16SessionManagementProtoP\x01Z\x13sessionmanagementv1\xa2\x02\x04NIMS\xaa\x02\x38NationalInstruments.MeasurementLink.SessionManagement.V1\xca\x02\'NI\\MeasurementLink\\SessionManagement\\V1\xea\x02*NI::MeasurementLink::SessionManagement::V1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ni.measurementlink.sessionmanagement.v1.session_management_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n+com.ni.measurementlink.sessionmanagement.v1B\026SessionManagementProtoP\001Z\023sessionmanagementv1\242\002\004NIMS\252\0028NationalInstruments.MeasurementLink.SessionManagement.V1\312\002\'NI\\MeasurementLink\\SessionManagement\\V1\352\002*NI::MeasurementLink::SessionManagement::V1'
  _RESERVESESSIONSRESPONSE_GROUPMAPPINGSENTRY._options = None
  _RESERVESESSIONSRESPONSE_GROUPMAPPINGSENTRY._serialized_options = b'8\001'
  _SESSIONINFORMATION._serialized_start=175
  _SESSIONINFORMATION._serialized_end=442
  _CHANNELMAPPING._serialized_start=445
  _CHANNELMAPPING._serialized_end=581
  _MULTIPLEXERSESSIONINFORMATION._serialized_start=584
  _MULTIPLEXERSESSIONINFORMATION._serialized_end=732
  _RESERVESESSIONSREQUEST._serialized_start=735
  _RESERVESESSIONSREQUEST._serialized_end=908
  _RESERVESESSIONSRESPONSE._serialized_start=911
  _RESERVESESSIONSRESPONSE._serialized_end=1343
  _RESERVESESSIONSRESPONSE_GROUPMAPPINGSENTRY._serialized_start=1228
  _RESERVESESSIONSRESPONSE_GROUPMAPPINGSENTRY._serialized_end=1343
  _UNRESERVESESSIONSREQUEST._serialized_start=1345
  _UNRESERVESESSIONSREQUEST._serialized_end=1450
  _UNRESERVESESSIONSRESPONSE._serialized_start=1452
  _UNRESERVESESSIONSRESPONSE._serialized_end=1479
  _REGISTERSESSIONSREQUEST._serialized_start=1481
  _REGISTERSESSIONSREQUEST._serialized_end=1585
  _REGISTERSESSIONSRESPONSE._serialized_start=1587
  _REGISTERSESSIONSRESPONSE._serialized_end=1613
  _UNREGISTERSESSIONSREQUEST._serialized_start=1615
  _UNREGISTERSESSIONSREQUEST._serialized_end=1721
  _UNREGISTERSESSIONSRESPONSE._serialized_start=1723
  _UNREGISTERSESSIONSRESPONSE._serialized_end=1751
  _RESERVEALLREGISTEREDSESSIONSREQUEST._serialized_start=1753
  _RESERVEALLREGISTEREDSESSIONSREQUEST._serialized_end=1851
  _RESERVEALLREGISTEREDSESSIONSRESPONSE._serialized_start=1853
  _RESERVEALLREGISTEREDSESSIONSRESPONSE._serialized_end=1970
  _REGISTERMULTIPLEXERSESSIONSREQUEST._serialized_start=1973
  _REGISTERMULTIPLEXERSESSIONSREQUEST._serialized_end=2111
  _REGISTERMULTIPLEXERSESSIONSRESPONSE._serialized_start=2113
  _REGISTERMULTIPLEXERSESSIONSRESPONSE._serialized_end=2150
  _UNREGISTERMULTIPLEXERSESSIONSREQUEST._serialized_start=2153
  _UNREGISTERMULTIPLEXERSESSIONSREQUEST._serialized_end=2293
  _UNREGISTERMULTIPLEXERSESSIONSRESPONSE._serialized_start=2295
  _UNREGISTERMULTIPLEXERSESSIONSRESPONSE._serialized_end=2334
  _GETMULTIPLEXERSESSIONSREQUEST._serialized_start=2336
  _GETMULTIPLEXERSESSIONSREQUEST._serialized_end=2456
  _GETMULTIPLEXERSESSIONSRESPONSE._serialized_start=2459
  _GETMULTIPLEXERSESSIONSRESPONSE._serialized_end=2593
  _GETALLREGISTEREDMULTIPLEXERSESSIONSREQUEST._serialized_start=2595
  _GETALLREGISTEREDMULTIPLEXERSESSIONSREQUEST._serialized_end=2668
  _GETALLREGISTEREDMULTIPLEXERSESSIONSRESPONSE._serialized_start=2671
  _GETALLREGISTEREDMULTIPLEXERSESSIONSRESPONSE._serialized_end=2818
  _RESOLVEDPINSORRELAYS._serialized_start=2820
  _RESOLVEDPINSORRELAYS._serialized_end=2870
  _GETSESSIONSREQUEST._serialized_start=2872
  _GETSESSIONSREQUEST._serialized_end=2949
  _GETSESSIONSRESPONSE._serialized_start=2952
  _GETSESSIONSRESPONSE._serialized_end=3154
  _SESSIONMANAGEMENTSERVICE._serialized_start=3157
  _SESSIONMANAGEMENTSERVICE._serialized_end=4897
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import ni.measurementlink.pin_map_context_pb2
import session_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class SessionInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    CHANNEL_LIST_FIELD_NUMBER: builtins.int
    INSTRUMENT_TYPE_ID_FIELD_NUMBER: builtins.int
    SESSION_EXISTS_FIELD_NUMBER: builtins.int
    SESSION_RESERVED_FIELD_NUMBER: builtins.int
    CHANNEL_MAPPINGS_FIELD_NUMBER: builtins.int
    resource_name: builtins.str
    """Resource name used to open this session in the driver.
    This field is readonly.
    """
    channel_list: builtins.str
    """Channel list used for driver initialization and measurement methods.
    This field is empty for any SessionInformation returned from ReserveAllRegisteredSessions.
    This field is readonly.
    """
    instrument_type_id: builtins.str
    """Instrument type ID to identify which type of instrument the session represents.
    The session management service has built in instrument definitions using the following NI driver based instrument type ids:
         "niDCPower"
         "niDigitalPattern"
         "niScope"
         "niDMM"
         "niDAQmx"
         "niFGen"
         "niRelayDriver"
    For custom instruments the user defined instrument type id is defined in the pin map file or custom session management plugin service.
    This field is readonly.
    """
    session_exists: builtins.bool
    """Indicates whether the session has been created and registered with the Session Manager.
    This field is readonly.
    """
    session_reserved: builtins.bool
    """Indicates whether the session has been reserved with the Session Manager.
    This field is readonly.
    """
    @property
    def session(self) -> session_pb2.Session:
        """Session identifier used to identify the session in the session management service, as well as in driver services such as grpc-device.
        This field is readonly.
        """

    @property
    def channel_mappings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ChannelMapping]:
        """List of site and I/O resource mappings with optional multiplexer information for each channel in the channel_list.
        Each item represents a channel-to-I/O-resource connection for this instrument resource. In the case of shared pins, there is a separate item for each connection.
        This field is empty for any SessionInformation returned from ReserveAllRegisteredSessions.
        This field is readonly.
        """

    def __init__(
        self,
        *,
        session: session_pb2.Session | None = ...,
        resource_name: builtins.str = ...,
        channel_list: builtins.str = ...,
        instrument_type_id: builtins.str = ...,
        session_exists: builtins.bool = ...,
        session_reserved: builtins.bool = ...,
        channel_mappings: collections.abc.Iterable[global___ChannelMapping] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["session", b"session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["channel_list", b"channel_list", "channel_mappings", b"channel_mappings", "instrument_type_id", b"instrument_type_id", "resource_name", b"resource_name", "session", b"session", "session_exists", b"session_exists", "session_reserved", b"session_reserved"]) -> None: ...

global___SessionInformation = SessionInformation

@typing.final
class ChannelMapping(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIN_OR_RELAY_NAME_FIELD_NUMBER: builtins.int
    SITE_FIELD_NUMBER: builtins.int
    CHANNEL_FIELD_NUMBER: builtins.int
    MULTIPLEXER_RESOURCE_NAME_FIELD_NUMBER: builtins.int
    MULTIPLEXER_ROUTE_FIELD_NUMBER: builtins.int
    pin_or_relay_name: builtins.str
    """The I/O resource that is mapped to a channel."""
    site: builtins.int
    """The site on which the I/O resource is mapped to a channel.
    For system pins/relays the site number is -1 since they do not belong to a specific site.
    """
    channel: builtins.str
    """The channel to which the I/O resource is mapped on this site."""
    multiplexer_resource_name: builtins.str
    """The multiplexer resource name is used to open the multiplexer session in the driver."""
    multiplexer_route: builtins.str
    """The multiplexer route through which the pin is connected to an instrument's channel."""
    def __init__(
        self,
        *,
        pin_or_relay_name: builtins.str = ...,
        site: builtins.int = ...,
        channel: builtins.str = ...,
        multiplexer_resource_name: builtins.str = ...,
        multiplexer_route: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["channel", b"channel", "multiplexer_resource_name", b"multiplexer_resource_name", "multiplexer_route", b"multiplexer_route", "pin_or_relay_name", b"pin_or_relay_name", "site", b"site"]) -> None: ...

global___ChannelMapping = ChannelMapping

@typing.final
class MultiplexerSessionInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_FIELD_NUMBER: builtins.int
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    MULTIPLEXER_TYPE_ID_FIELD_NUMBER: builtins.int
    SESSION_EXISTS_FIELD_NUMBER: builtins.int
    resource_name: builtins.str
    """Resource name is used to open this session in the driver.
    This field is readonly.
    """
    multiplexer_type_id: builtins.str
    """User-defined identifier for the multiplexer type in the pin map editor.
    This field is readonly.
    """
    session_exists: builtins.bool
    """Indicates whether the session exists in the Session Manager. This indicates whether the session has been created.
    This field is readonly.
    """
    @property
    def session(self) -> session_pb2.Session:
        """Session identifier used to identify the session in the session management service, as well as in driver services such as grpc-device.
        This field is readonly.
        """

    def __init__(
        self,
        *,
        session: session_pb2.Session | None = ...,
        resource_name: builtins.str = ...,
        multiplexer_type_id: builtins.str = ...,
        session_exists: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["session", b"session"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_type_id", b"multiplexer_type_id", "resource_name", b"resource_name", "session", b"session", "session_exists", b"session_exists"]) -> None: ...

global___MultiplexerSessionInformation = MultiplexerSessionInformation

@typing.final
class ReserveSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIN_MAP_CONTEXT_FIELD_NUMBER: builtins.int
    PIN_OR_RELAY_NAMES_FIELD_NUMBER: builtins.int
    INSTRUMENT_TYPE_ID_FIELD_NUMBER: builtins.int
    TIMEOUT_IN_MILLISECONDS_FIELD_NUMBER: builtins.int
    instrument_type_id: builtins.str
    """Optional. Instrument type ID for the measurement. If unspecified, reserve sessions for all instrument types connected in the registered pin map resource.
    The session management service has built in instrument definitions using the following NI driver based instrument type ids:
         "niDCPower"
         "niDigitalPattern"
         "niScope"
         "niDMM"
         "niDAQmx"
         "niFGen"
         "niRelayDriver"
    For custom instruments the user defined instrument type id is defined in the pin map file or custom session management plugin service.
    """
    timeout_in_milliseconds: builtins.int
    """Optional. Timeout for the reservation request.
    Allowed values: 0 (non-blocking, fails immediately if resources cannot be reserved), -1 (infinite timeout), or any other positive numeric value (wait for that number of milliseconds)
    """
    @property
    def pin_map_context(self) -> ni.measurementlink.pin_map_context_pb2.PinMapContext:
        """Optional. Includes the pin map ID for the pin map in the Pin Map Service, as well as the list of sites for the measurement. If unspecified, specify non-pin I/O resources for pin_or_relay_names."""

    @property
    def pin_or_relay_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """Optional. List of I/O resources (pins, pin groups, relays, relay groups, or channels) to use for the measurement. If unspecified, reserve sessions for all pins and relays in the registered pin map resource."""

    def __init__(
        self,
        *,
        pin_map_context: ni.measurementlink.pin_map_context_pb2.PinMapContext | None = ...,
        pin_or_relay_names: collections.abc.Iterable[builtins.str] | None = ...,
        instrument_type_id: builtins.str = ...,
        timeout_in_milliseconds: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pin_map_context", b"pin_map_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["instrument_type_id", b"instrument_type_id", "pin_map_context", b"pin_map_context", "pin_or_relay_names", b"pin_or_relay_names", "timeout_in_milliseconds", b"timeout_in_milliseconds"]) -> None: ...

global___ReserveSessionsRequest = ReserveSessionsRequest

@typing.final
class ReserveSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class GroupMappingsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        @property
        def value(self) -> global___ResolvedPinsOrRelays: ...
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: global___ResolvedPinsOrRelays | None = ...,
        ) -> None: ...
        def HasField(self, field_name: typing.Literal["value", b"value"]) -> builtins.bool: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    SESSIONS_FIELD_NUMBER: builtins.int
    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    GROUP_MAPPINGS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """List of information needed to create or use each session for the given I/O resource, site, and instrument type ID."""

    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """List of information needed to create or use each multiplexer session for the given I/O resource, site, and instrument type ID."""

    @property
    def group_mappings(self) -> google.protobuf.internal.containers.MessageMap[builtins.str, global___ResolvedPinsOrRelays]:
        """Represents the mapping between pin or relay groups and their respective pin or relay names."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
        group_mappings: collections.abc.Mapping[builtins.str, global___ResolvedPinsOrRelays] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["group_mappings", b"group_mappings", "multiplexer_sessions", b"multiplexer_sessions", "sessions", b"sessions"]) -> None: ...

global___ReserveSessionsResponse = ReserveSessionsResponse

@typing.final
class UnreserveSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """Required. List of information of sessions to be unreserved in the session management service."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sessions", b"sessions"]) -> None: ...

global___UnreserveSessionsRequest = UnreserveSessionsRequest

@typing.final
class UnreserveSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnreserveSessionsResponse = UnreserveSessionsResponse

@typing.final
class RegisterSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """Required. List of sessions to register with the session management service to track as the sessions are open."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sessions", b"sessions"]) -> None: ...

global___RegisterSessionsRequest = RegisterSessionsRequest

@typing.final
class RegisterSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterSessionsResponse = RegisterSessionsResponse

@typing.final
class UnregisterSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """Required. List of sessions to unregister with the session management service to mark them as sessions were closed."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sessions", b"sessions"]) -> None: ...

global___UnregisterSessionsRequest = UnregisterSessionsRequest

@typing.final
class UnregisterSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnregisterSessionsResponse = UnregisterSessionsResponse

@typing.final
class ReserveAllRegisteredSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TIMEOUT_IN_MILLISECONDS_FIELD_NUMBER: builtins.int
    INSTRUMENT_TYPE_ID_FIELD_NUMBER: builtins.int
    timeout_in_milliseconds: builtins.int
    """Optional. Timeout for the reservation request.
    Allowed values: 0 (non-blocking, fails immediately if resources cannot be reserved), -1 (infinite timeout), or any other positive numeric value (wait for that number of milliseconds)
    """
    instrument_type_id: builtins.str
    """Optional. Instrument type ID of the registered sessions to reserve. If unspecified, reserve sessions for all instrument types connected in the registered pin map resource.
    The session management service has built in instrument definitions using the following NI driver based instrument type ids:
         "niDCPower"
         "niDigitalPattern"
         "niScope"
         "niDMM"
         "niDAQmx"
         "niFGen"
         "niRelayDriver"
    For custom instruments the user defined instrument type id is defined in the pin map file or custom session management plugin service.
    """
    def __init__(
        self,
        *,
        timeout_in_milliseconds: builtins.int = ...,
        instrument_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instrument_type_id", b"instrument_type_id", "timeout_in_milliseconds", b"timeout_in_milliseconds"]) -> None: ...

global___ReserveAllRegisteredSessionsRequest = ReserveAllRegisteredSessionsRequest

@typing.final
class ReserveAllRegisteredSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """Sessions currently registered in the session management service."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["sessions", b"sessions"]) -> None: ...

global___ReserveAllRegisteredSessionsResponse = ReserveAllRegisteredSessionsResponse

@typing.final
class RegisterMultiplexerSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """Required. List of multiplexer sessions to register with the session management service to track as the sessions are open."""

    def __init__(
        self,
        *,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_sessions", b"multiplexer_sessions"]) -> None: ...

global___RegisterMultiplexerSessionsRequest = RegisterMultiplexerSessionsRequest

@typing.final
class RegisterMultiplexerSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___RegisterMultiplexerSessionsResponse = RegisterMultiplexerSessionsResponse

@typing.final
class UnregisterMultiplexerSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """Required. List of multiplexer sessions to unregister with the session management service to mark them as sessions were closed."""

    def __init__(
        self,
        *,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_sessions", b"multiplexer_sessions"]) -> None: ...

global___UnregisterMultiplexerSessionsRequest = UnregisterMultiplexerSessionsRequest

@typing.final
class UnregisterMultiplexerSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UnregisterMultiplexerSessionsResponse = UnregisterMultiplexerSessionsResponse

@typing.final
class GetMultiplexerSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIN_MAP_CONTEXT_FIELD_NUMBER: builtins.int
    MULTIPLEXER_TYPE_ID_FIELD_NUMBER: builtins.int
    multiplexer_type_id: builtins.str
    """Optional. User-defined identifier for the multiplexer type in the pin map editor.
    If unspecified, information for all multiplexer types is returned.
    """
    @property
    def pin_map_context(self) -> ni.measurementlink.pin_map_context_pb2.PinMapContext:
        """Required. Includes the pin map ID for the pin map in the Pin Map Service, as well as the list of sites for the measurement."""

    def __init__(
        self,
        *,
        pin_map_context: ni.measurementlink.pin_map_context_pb2.PinMapContext | None = ...,
        multiplexer_type_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["pin_map_context", b"pin_map_context"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_type_id", b"multiplexer_type_id", "pin_map_context", b"pin_map_context"]) -> None: ...

global___GetMultiplexerSessionsRequest = GetMultiplexerSessionsRequest

@typing.final
class GetMultiplexerSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """List of information needed to create or use each multiplexer session for the given pin map context and multiplexer type ID."""

    def __init__(
        self,
        *,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_sessions", b"multiplexer_sessions"]) -> None: ...

global___GetMultiplexerSessionsResponse = GetMultiplexerSessionsResponse

@typing.final
class GetAllRegisteredMultiplexerSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLEXER_TYPE_ID_FIELD_NUMBER: builtins.int
    multiplexer_type_id: builtins.str
    """Optional. User-defined identifier for the multiplexer type in the pin map editor.
    If unspecified, information for all registered multiplexer types is returned.
    """
    def __init__(
        self,
        *,
        multiplexer_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_type_id", b"multiplexer_type_id"]) -> None: ...

global___GetAllRegisteredMultiplexerSessionsRequest = GetAllRegisteredMultiplexerSessionsRequest

@typing.final
class GetAllRegisteredMultiplexerSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """Multiplexer sessions currently registered in the session management service."""

    def __init__(
        self,
        *,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_sessions", b"multiplexer_sessions"]) -> None: ...

global___GetAllRegisteredMultiplexerSessionsResponse = GetAllRegisteredMultiplexerSessionsResponse

@typing.final
class ResolvedPinsOrRelays(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PIN_OR_RELAY_NAMES_FIELD_NUMBER: builtins.int
    @property
    def pin_or_relay_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """List of pin or relay names in the pin or relay group."""

    def __init__(
        self,
        *,
        pin_or_relay_names: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["pin_or_relay_names", b"pin_or_relay_names"]) -> None: ...

global___ResolvedPinsOrRelays = ResolvedPinsOrRelays

@typing.final
class GetSessionsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INSTRUMENT_TYPE_ID_FIELD_NUMBER: builtins.int
    MULTIPLEXER_TYPE_ID_FIELD_NUMBER: builtins.int
    instrument_type_id: builtins.str
    """Optional. Instrument type ID of the instruments.
    If unspecified, information for all instrument types is returned.
    """
    multiplexer_type_id: builtins.str
    """Optional. User-defined identifier for the multiplexers.
    If unspecified, information for all registered multiplexer types is returned.
    """
    def __init__(
        self,
        *,
        instrument_type_id: builtins.str = ...,
        multiplexer_type_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["instrument_type_id", b"instrument_type_id", "multiplexer_type_id", b"multiplexer_type_id"]) -> None: ...

global___GetSessionsRequest = GetSessionsRequest

@typing.final
class GetSessionsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSIONS_FIELD_NUMBER: builtins.int
    MULTIPLEXER_SESSIONS_FIELD_NUMBER: builtins.int
    @property
    def sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SessionInformation]:
        """List of reserved or registered instrument sessions."""

    @property
    def multiplexer_sessions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___MultiplexerSessionInformation]:
        """List of registered multiplexer sessions."""

    def __init__(
        self,
        *,
        sessions: collections.abc.Iterable[global___SessionInformation] | None = ...,
        multiplexer_sessions: collections.abc.Iterable[global___MultiplexerSessionInformation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["multiplexer_sessions", b"multiplexer_sessions", "sessions", b"sessions"]) -> None: ...

global___GetSessionsResponse = GetSessionsResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import grpc
import grpc.aio
import ni.measurementlink.sessionmanagement.v1.session_management_service_pb2
import typing

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class SessionManagementServiceStub:
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    ReserveSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsResponse,
    ]
    """Reserve session(s) for the given I/O resources (pins, relays, channels), sites, and instrument type ID and returns the information needed to create or access the session.
    Also reserves the session so other processes cannot access it with a ReserveSessions() call.
    Status Codes for errors:
    - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map
        - Pin or relay name does not match any pin, pin group, relay, or relay group names in the pin map
        - Timeout specified is less than -1.
    - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
    - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
    """

    UnreserveSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsResponse,
    ]
    """Unreserves sessions so they can be accessed by other clients.
    - RESOURCE_EXHAUSTED:
        - Error occurred while unreserving sessions.
    """

    RegisterSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsResponse,
    ]
    """Registers the sessions with this service. Indicates that the sessions are open and will need to be closed later.
    Status Codes for errors:
    - ALREADY_EXISTS:
        - Session by the same name is already registered.
    - INVALID_ARGUMENT:
        - Session names list has an empty string.
    """

    UnregisterSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsResponse,
    ]
    """Unregisters the sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    ReserveAllRegisteredSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsResponse,
    ]
    """Reserves and gets all sessions currently registered with this service.
    - INVALID_ARGUMENT:
        - Timeout specified is less than -1.
    - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
    """

    RegisterMultiplexerSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsResponse,
    ]
    """Registers the multiplexer sessions with this service. Indicates that the sessions are open and will need to be closed later.
    Status Codes for errors:
    - ALREADY_EXISTS:
        - Session by the same name is already registered.
    - INVALID_ARGUMENT:
        - Session names list has an empty string.
    """

    UnregisterMultiplexerSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsResponse,
    ]
    """Unregisters the multiplexer sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    GetMultiplexerSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsResponse,
    ]
    """Gets all the connected multiplexer session(s) for the given pin map context and returns information needed to create or access the session.
    Status Codes for errors:
    - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map.
    - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
    """

    GetAllRegisteredMultiplexerSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsResponse,
    ]
    """Gets all multiplexer sessions currently registered with this service."""

    GetSessions: grpc.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsResponse,
    ]
    """Gets all reserved or registered sessions for the specified instrument and multiplexer types."""

class SessionManagementServiceAsyncStub:
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site."""

    ReserveSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsResponse,
    ]
    """Reserve session(s) for the given I/O resources (pins, relays, channels), sites, and instrument type ID and returns the information needed to create or access the session.
    Also reserves the session so other processes cannot access it with a ReserveSessions() call.
    Status Codes for errors:
    - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map
        - Pin or relay name does not match any pin, pin group, relay, or relay group names in the pin map
        - Timeout specified is less than -1.
    - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
    - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
    """

    UnreserveSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsResponse,
    ]
    """Unreserves sessions so they can be accessed by other clients.
    - RESOURCE_EXHAUSTED:
        - Error occurred while unreserving sessions.
    """

    RegisterSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsResponse,
    ]
    """Registers the sessions with this service. Indicates that the sessions are open and will need to be closed later.
    Status Codes for errors:
    - ALREADY_EXISTS:
        - Session by the same name is already registered.
    - INVALID_ARGUMENT:
        - Session names list has an empty string.
    """

    UnregisterSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsResponse,
    ]
    """Unregisters the sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    ReserveAllRegisteredSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsResponse,
    ]
    """Reserves and gets all sessions currently registered with this service.
    - INVALID_ARGUMENT:
        - Timeout specified is less than -1.
    - UNAVAILABLE:
        - Session(s) were already reserved and didn't become available before the specified timeout expired.
    """

    RegisterMultiplexerSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsResponse,
    ]
    """Registers the multiplexer sessions with this service. Indicates that the sessions are open and will need to be closed later.
    Status Codes for errors:
    - ALREADY_EXISTS:
        - Session by the same name is already registered.
    - INVALID_ARGUMENT:
        - Session names list has an empty string.
    """

    UnregisterMultiplexerSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsResponse,
    ]
    """Unregisters the multiplexer sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    GetMultiplexerSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsResponse,
    ]
    """Gets all the connected multiplexer session(s) for the given pin map context and returns information needed to create or access the session.
    Status Codes for errors:
    - INVALID_ARGUMENT:
        - Pin Map Context references a site number that is not defined in the pin map.
    - NOT_FOUND:
        - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
    """

    GetAllRegisteredMultiplexerSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsResponse,
    ]
    """Gets all multiplexer sessions currently registered with this service."""

    GetSessions: grpc.aio.UnaryUnaryMultiCallable[
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsRequest,
        ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsResponse,
    ]
    """Gets all reserved or registered sessions for the specified instrument and multiplexer types."""

class SessionManagementServiceServicer(metaclass=abc.ABCMeta):
    """Service to keep track of open sessions used by measurement services, and to allow measurement services to access sessions by I/O resource and site."""

    @abc.abstractmethod
    def ReserveSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveSessionsResponse]]:
        """Reserve session(s) for the given I/O resources (pins, relays, channels), sites, and instrument type ID and returns the information needed to create or access the session.
        Also reserves the session so other processes cannot access it with a ReserveSessions() call.
        Status Codes for errors:
        - INVALID_ARGUMENT:
            - Pin Map Context references a site number that is not defined in the pin map
            - Pin or relay name does not match any pin, pin group, relay, or relay group names in the pin map
            - Timeout specified is less than -1.
        - NOT_FOUND:
            - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
        - UNAVAILABLE:
            - Session(s) were already reserved and didn't become available before the specified timeout expired.
        """

    @abc.abstractmethod
    def UnreserveSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnreserveSessionsResponse]]:
        """Unreserves sessions so they can be accessed by other clients.
        - RESOURCE_EXHAUSTED:
            - Error occurred while unreserving sessions.
        """

    @abc.abstractmethod
    def RegisterSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterSessionsResponse]]:
        """Registers the sessions with this service. Indicates that the sessions are open and will need to be closed later.
        Status Codes for errors:
        - ALREADY_EXISTS:
            - Session by the same name is already registered.
        - INVALID_ARGUMENT:
            - Session names list has an empty string.
        """

    @abc.abstractmethod
    def UnregisterSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterSessionsResponse]]:
        """Unregisters the sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    @abc.abstractmethod
    def ReserveAllRegisteredSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.ReserveAllRegisteredSessionsResponse]]:
        """Reserves and gets all sessions currently registered with this service.
        - INVALID_ARGUMENT:
            - Timeout specified is less than -1.
        - UNAVAILABLE:
            - Session(s) were already reserved and didn't become available before the specified timeout expired.
        """

    @abc.abstractmethod
    def RegisterMultiplexerSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.RegisterMultiplexerSessionsResponse]]:
        """Registers the multiplexer sessions with this service. Indicates that the sessions are open and will need to be closed later.
        Status Codes for errors:
        - ALREADY_EXISTS:
            - Session by the same name is already registered.
        - INVALID_ARGUMENT:
            - Session names list has an empty string.
        """

    @abc.abstractmethod
    def UnregisterMultiplexerSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.UnregisterMultiplexerSessionsResponse]]:
        """Unregisters the multiplexer sessions with this service. Indicates that the sessions have been closed and will need to be reopened before they can be used again."""

    @abc.abstractmethod
    def GetMultiplexerSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetMultiplexerSessionsResponse]]:
        """Gets all the connected multiplexer session(s) for the given pin map context and returns information needed to create or access the session.
        Status Codes for errors:
        - INVALID_ARGUMENT:
            - Pin Map Context references a site number that is not defined in the pin map.
        - NOT_FOUND:
            - Pin Map Context has a pin map ID that does not match any pin maps registered with the Pin Map Service.
        """

    @abc.abstractmethod
    def GetAllRegisteredMultiplexerSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetAllRegisteredMultiplexerSessionsResponse]]:
        """Gets all multiplexer sessions currently registered with this service."""

    @abc.abstractmethod
    def GetSessions(
        self,
        request: ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsResponse, collections.abc.Awaitable[ni.measurementlink.sessionmanagement.v1.session_management_service_pb2.GetSessionsResponse]]:
        """Gets all reserved or registered sessions for the specified instrument and multiplexer types."""

def add_SessionManagementServiceServicer_to_server(servicer: SessionManagementServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...
